@@ -53,7 +53,10 @@ use strict;
 use base 'Catalyst::View::MicroMason';
 
 __PACKAGE__->config(
-    Mixins => [qw( -Filters )], # to use |h and |u
+    # -Filters      : to use |h and |u
+    # -ExecuteCache : to cache template output
+    # -CompileCache : to cache the templates
+    Mixins => [qw( -Filters -CompileCache )], 
 );
     
 =head1 NAME
